[![Build Status](https://travis-ci.com/bussilab/py-bussilab.svg?branch=master)](https://travis-ci.com/bussilab/py-bussilab)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/bussilab/py-bussilab.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/bussilab/py-bussilab/context:python)
[![Total alerts](https://img.shields.io/lgtm/alerts/g/bussilab/py-bussilab.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/bussilab/py-bussilab/alerts/)
[![codecov](https://codecov.io/gh/bussilab/py-bussilab/branch/master/graph/badge.svg)](https://codecov.io/gh/bussilab/py-bussilab)

A package collecting a heterogeneous set of tools.

This package collects a number of tools that are useful enough to be distributed but too small to deserve being published as separate packages.
Documentation can be browsed at [this page](https://bussilab.github.io/doc-py-bussilab).
To install package and dependencies with pip:

```
pip install bussilab
```

To install package and dependencies with conda or macports, see [documentation](https://bussilab.github.io/doc-py-bussilab).

